%TRANSIENT class definition
%
%   Usage:
%      transient=transient();

classdef transient
	properties (SetAccess=public) 
		isprognostic      = modelfield('default',0,'marshall',true,'format','Boolean');
		isdiagnostic      = modelfield('default',0,'marshall',true,'format','Boolean');
		isthermal         = modelfield('default',0,'marshall',true,'format','Boolean');
		isgroundingline   = modelfield('default',0,'marshall',true,'format','Boolean');
		requested_outputs = modelfield('default',NaN,'marshall',true,'format','DoubleMat','mattype',3);
	end
	methods
		function obj = transient(varargin) % {{{
			switch nargin
				case 0
					obj=setdefaultparameters(obj);
				case 1
					in=varargin{1};
					if (isa(in,'numeric') & in==0),
						% requesting templates do nothing
					else
						error('constructor not supported');
					end 
				otherwise
					error('constructor not supported');
			end
		end % }}}
		function obj = setdefaultparameters(obj) % {{{

			%first, use the defaults provided by the properties definition above. 
			fieldnames=fields(obj);
			for i=1:length(fieldnames),
				fieldname=fieldnames{i};
				obj.(fieldname)=obj.(fieldname).default;
			end

			%full analysis: Diagnostic, Prognostic and Thermal but no groundingline migration for now
			obj.isprognostic=1;
			obj.isdiagnostic=1;
			obj.isthermal=1;
			obj.isgroundingline=0;

		end % }}}
		function checkconsistency(obj,md,solution,analyses) % {{{

			%Early return
			if solution~=TransientSolutionEnum, return; end

			checkfield(md,'transient.isprognostic','numel',1,'values',[0 1]);
			checkfield(md,'transient.isdiagnostic','numel',1,'values',[0 1]);
			checkfield(md,'transient.isthermal','numel',1,'values',[0 1]);
			checkfield(md,'transient.isgroundingline','numel',1,'values',[0 1]);

			%check that groundingline is not activated in serial model
			if md.transient.isgroundingline & strcmp(md.cluster.name,'none'),
				checkmessage(['model not consistent: ' md.private.solution ' is only implemented in parallel mode !']);
			end

			%Check that grounding line migration is in 2d
			if md.transient.isgroundingline & md.mesh.dimension~=2
				checkmessage(['model not consistent: for a ' md.private.solution ' computation, the grounding line module is only implemented in 2d !']);
			end

		end % }}}
		function disp(obj) % {{{
			disp(sprintf('   balance thickness solution parameters:'));

			fielddisplay(obj,'isprognostic','indicates if a prognostic solution is used in the transient');
			fielddisplay(obj,'isthermal','indicates if a thermal solution is used in the transient');
			fielddisplay(obj,'isdiagnostic','indicates if a diagnostic solution is used in the transient');
			fielddisplay(obj,'isgroundingline','indicates if a groundingline migration is used in the transient');

		end % }}}
	end
end
